==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/ConnectToSourceOracleSyncTaskInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.ConnectToSourceOracleSyncTaskInputArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Input for the task that validates Oracle database connection
 * @property sourceConnectionInfo Information for connecting to Oracle source
 */
public data class ConnectToSourceOracleSyncTaskInputArgs(
    public val sourceConnectionInfo: Output<OracleConnectionInfoArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.ConnectToSourceOracleSyncTaskInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.datamigration.inputs.ConnectToSourceOracleSyncTaskInputArgs =
        com.pulumi.azurenative.datamigration.inputs.ConnectToSourceOracleSyncTaskInputArgs.builder()
            .sourceConnectionInfo(
                sourceConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ConnectToSourceOracleSyncTaskInputArgs].
 */
@PulumiTagMarker
public class ConnectToSourceOracleSyncTaskInputArgsBuilder internal constructor() {
    private var sourceConnectionInfo: Output<OracleConnectionInfoArgs>? = null

    /**
     * @param value Information for connecting to Oracle source
     */
    @JvmName("qkcxqwchhcdhaxba")
    public suspend fun sourceConnectionInfo(`value`: Output<OracleConnectionInfoArgs>) {
        this.sourceConnectionInfo = value
    }

    /**
     * @param value Information for connecting to Oracle source
     */
    @JvmName("gcltcpweeydscgjf")
    public suspend fun sourceConnectionInfo(`value`: OracleConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param argument Information for connecting to Oracle source
     */
    @JvmName("cmbxumvyaknrrfdo")
    public suspend
    fun sourceConnectionInfo(argument: suspend OracleConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = OracleConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sourceConnectionInfo = mapped
    }

    internal fun build(): ConnectToSourceOracleSyncTaskInputArgs =
        ConnectToSourceOracleSyncTaskInputArgs(
            sourceConnectionInfo = sourceConnectionInfo ?: throw
                PulumiNullFieldException("sourceConnectionInfo"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/ConnectToSourceOracleSyncTaskInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.ConnectToSourceOracleSyncTaskInputArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Input for the task that validates Oracle database connection
 * @property sourceConnectionInfo Information for connecting to Oracle source
 */
public data class ConnectToSourceOracleSyncTaskInputArgs(
    public val sourceConnectionInfo: Output<OracleConnectionInfoArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.ConnectToSourceOracleSyncTaskInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.datamigration.inputs.ConnectToSourceOracleSyncTaskInputArgs =
        com.pulumi.azurenative.datamigration.inputs.ConnectToSourceOracleSyncTaskInputArgs.builder()
            .sourceConnectionInfo(
                sourceConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ConnectToSourceOracleSyncTaskInputArgs].
 */
@PulumiTagMarker
public class ConnectToSourceOracleSyncTaskInputArgsBuilder internal constructor() {
    private var sourceConnectionInfo: Output<OracleConnectionInfoArgs>? = null

    /**
     * @param value Information for connecting to Oracle source
     */
    @JvmName("henyvdegbqcppnkk")
    public suspend fun sourceConnectionInfo(`value`: Output<OracleConnectionInfoArgs>) {
        this.sourceConnectionInfo = value
    }

    /**
     * @param value Information for connecting to Oracle source
     */
    @JvmName("aoxcnirysmoypogk")
    public suspend fun sourceConnectionInfo(`value`: OracleConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param argument Information for connecting to Oracle source
     */
    @JvmName("eenevqriuiwsowxg")
    public suspend
    fun sourceConnectionInfo(argument: suspend OracleConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = OracleConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sourceConnectionInfo = mapped
    }

    internal fun build(): ConnectToSourceOracleSyncTaskInputArgs =
        ConnectToSourceOracleSyncTaskInputArgs(
            sourceConnectionInfo = sourceConnectionInfo ?: throw
                PulumiNullFieldException("sourceConnectionInfo"),
        )
}
